@@ -33,8 +33,8 @@ fn bench_adi_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_conv_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = Conv::new((0..10).map(|x| x as ValueType).collect(), candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = Conv::new((0..10).map(|x| x as ValueType).collect(), &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -44,8 +44,8 @@ fn bench_conv_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_conv_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = Conv::new((0..100).map(|x| x as ValueType).collect(), candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = Conv::new((0..100).map(|x| x as ValueType).collect(), &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -60,8 +60,8 @@ fn bench_cross(b: &mut test::Bencher) {
 		.map(|c| c.close)
 		.zip(RandomCandles::new().skip(15).take(1000).map(|c| c.close))
 		.collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = Cross::new((), candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = Cross::new((), &candles[0]).unwrap();
 	b.iter(|| method.next(iter.next().unwrap()))
 }
 
@@ -72,8 +72,8 @@ fn bench_cross_above(b: &mut test::Bencher) {
 		.map(|c| c.close)
 		.zip(RandomCandles::new().skip(15).take(1000).map(|c| c.close))
 		.collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = CrossAbove::new((), candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = CrossAbove::new((), &candles[0]).unwrap();
 	b.iter(|| method.next(iter.next().unwrap()))
 }
 
@@ -84,8 +84,8 @@ fn bench_cross_under(b: &mut test::Bencher) {
 		.map(|c| c.close)
 		.zip(RandomCandles::new().skip(15).take(1000).map(|c| c.close))
 		.collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = CrossUnder::new((), candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = CrossUnder::new((), &candles[0]).unwrap();
 	b.iter(|| method.next(iter.next().unwrap()))
 }
 
@@ -93,8 +93,8 @@ fn bench_cross_under(b: &mut test::Bencher) {
 #[bench]
 fn bench_sma_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = SMA::new(10, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = SMA::new(10, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -104,8 +104,8 @@ fn bench_sma_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_sma_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = SMA::new(100, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = SMA::new(100, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -116,8 +116,8 @@ fn bench_sma_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_wma_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = WMA::new(10, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = WMA::new(10, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -127,8 +127,8 @@ fn bench_wma_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_wma_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = WMA::new(100, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = WMA::new(100, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -139,8 +139,8 @@ fn bench_wma_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_ema_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = EMA::new(10, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = EMA::new(10, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -150,8 +150,8 @@ fn bench_ema_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_ema_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = EMA::new(100, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = EMA::new(100, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -162,8 +162,8 @@ fn bench_ema_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_dma_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = DMA::new(10, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = DMA::new(10, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -173,8 +173,8 @@ fn bench_dma_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_dma_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = DMA::new(100, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = DMA::new(100, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -185,8 +185,8 @@ fn bench_dma_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_tma_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = TMA::new(10, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = TMA::new(10, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -196,8 +196,8 @@ fn bench_tma_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_tma_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = TMA::new(100, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = TMA::new(100, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -208,8 +208,8 @@ fn bench_tma_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_dema_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = DEMA::new(10, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = DEMA::new(10, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -219,8 +219,8 @@ fn bench_dema_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_dema_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = DEMA::new(100, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = DEMA::new(100, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -231,8 +231,8 @@ fn bench_dema_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_tema_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = TEMA::new(10, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = TEMA::new(10, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -242,8 +242,8 @@ fn bench_tema_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_tema_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = TEMA::new(100, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = TEMA::new(100, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -254,8 +254,8 @@ fn bench_tema_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_smm_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = SMM::new(10, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = SMM::new(10, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -265,8 +265,8 @@ fn bench_smm_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_smm_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = SMM::new(100, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = SMM::new(100, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -277,8 +277,8 @@ fn bench_smm_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_hma_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = HMA::new(10, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = HMA::new(10, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -288,8 +288,8 @@ fn bench_hma_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_hma_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = HMA::new(100, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = HMA::new(100, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -300,8 +300,8 @@ fn bench_hma_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_lin_reg_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = LinReg::new(10, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = LinReg::new(10, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -311,8 +311,8 @@ fn bench_lin_reg_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_lin_reg_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = LinReg::new(100, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = LinReg::new(100, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -323,8 +323,8 @@ fn bench_lin_reg_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_derivative_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = Derivative::new(10, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = Derivative::new(10, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -334,8 +334,8 @@ fn bench_derivative_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_derivative_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = Derivative::new(100, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = Derivative::new(100, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -346,8 +346,8 @@ fn bench_derivative_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_integral_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = Integral::new(10, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = Integral::new(10, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -357,8 +357,8 @@ fn bench_integral_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_integral_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = Integral::new(100, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = Integral::new(100, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -369,8 +369,8 @@ fn bench_integral_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_momentum_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = Momentum::new(10, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = Momentum::new(10, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -380,8 +380,8 @@ fn bench_momentum_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_momentum_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = Momentum::new(100, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = Momentum::new(100, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -392,8 +392,8 @@ fn bench_momentum_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_past_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = Past::new(10, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = Past::new(10, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -403,8 +403,8 @@ fn bench_past_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_past_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = Past::new(100, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = Past::new(100, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -415,8 +415,8 @@ fn bench_past_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_rate_of_change_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = RateOfChange::new(10, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = RateOfChange::new(10, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -426,8 +426,8 @@ fn bench_rate_of_change_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_rate_of_change_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = RateOfChange::new(100, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = RateOfChange::new(100, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -438,8 +438,8 @@ fn bench_rate_of_change_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_reverse_signal_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = ReversalSignal::new(5, 5, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = ReversalSignal::new(5, 5, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -449,8 +449,8 @@ fn bench_reverse_signal_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_reverse_signal_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = ReversalSignal::new(50, 50, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = ReversalSignal::new(50, 50, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -461,8 +461,8 @@ fn bench_reverse_signal_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_reverse_low_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = LowerReversalSignal::new(5, 5, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = LowerReversalSignal::new(5, 5, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -472,8 +472,8 @@ fn bench_reverse_low_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_reverse_low_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = LowerReversalSignal::new(50, 50, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = LowerReversalSignal::new(50, 50, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -484,8 +484,8 @@ fn bench_reverse_low_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_reverse_high_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = LowerReversalSignal::new(5, 5, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = LowerReversalSignal::new(5, 5, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -495,8 +495,8 @@ fn bench_reverse_high_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_reverse_high_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = UpperReversalSignal::new(50, 50, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = UpperReversalSignal::new(50, 50, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -507,8 +507,8 @@ fn bench_reverse_high_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_rma_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = RMA::new(10, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = RMA::new(10, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -518,8 +518,8 @@ fn bench_rma_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_rma_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = RMA::new(100, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = RMA::new(100, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -530,8 +530,8 @@ fn bench_rma_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_st_dev_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = StDev::new(10, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = StDev::new(10, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -541,8 +541,8 @@ fn bench_st_dev_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_st_dev_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = StDev::new(100, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = StDev::new(100, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -553,8 +553,8 @@ fn bench_st_dev_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_swma_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = SWMA::new(10, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = SWMA::new(10, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -564,8 +564,8 @@ fn bench_swma_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_swma_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = SWMA::new(100, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = SWMA::new(100, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -576,8 +576,8 @@ fn bench_swma_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_trima_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = TRIMA::new(10, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = TRIMA::new(10, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -587,8 +587,8 @@ fn bench_trima_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_trima_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = TRIMA::new(100, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = TRIMA::new(100, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -599,8 +599,8 @@ fn bench_trima_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_linear_volatility_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = LinearVolatility::new(10, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = LinearVolatility::new(10, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -610,8 +610,8 @@ fn bench_linear_volatility_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_linear_volatility_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = LinearVolatility::new(100, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = LinearVolatility::new(100, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -622,30 +622,30 @@ fn bench_linear_volatility_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_vwma_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = VWMA::new(10, (candles[0].close, candles[0].volume)).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = VWMA::new(10, &(candles[0].close, candles[0].volume)).unwrap();
 	for _ in 0..10 {
 		let candle = iter.next().unwrap();
-		method.next((candle.close, candle.volume));
+		method.next(&(candle.close, candle.volume));
 	}
 	b.iter(|| {
 		let candle = iter.next().unwrap();
-		method.next((candle.close, candle.volume))
+		method.next(&(candle.close, candle.volume))
 	})
 }
 
 #[bench]
 fn bench_vwma_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = VWMA::new(100, (candles[0].close, candles[0].volume)).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = VWMA::new(100, &(candles[0].close, candles[0].volume)).unwrap();
 	for _ in 0..100 {
 		let candle = iter.next().unwrap();
-		method.next((candle.close, candle.volume));
+		method.next(&(candle.close, candle.volume));
 	}
 	b.iter(|| {
 		let candle = iter.next().unwrap();
-		method.next((candle.close, candle.volume))
+		method.next(&(candle.close, candle.volume))
 	})
 }
 
@@ -653,8 +653,8 @@ fn bench_vwma_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_highest_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = Highest::new(10, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = Highest::new(10, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -664,8 +664,8 @@ fn bench_highest_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_highest_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = Highest::new(100, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = Highest::new(100, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -676,8 +676,8 @@ fn bench_highest_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_lowest_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = Lowest::new(10, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = Lowest::new(10, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -687,8 +687,8 @@ fn bench_lowest_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_lowest_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = Lowest::new(100, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = Lowest::new(100, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -699,8 +699,8 @@ fn bench_lowest_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_highest_lowest_delta_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = HighestLowestDelta::new(10, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = HighestLowestDelta::new(10, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -710,8 +710,8 @@ fn bench_highest_lowest_delta_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_highest_lowest_delta_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = HighestLowestDelta::new(10, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = HighestLowestDelta::new(10, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -722,8 +722,8 @@ fn bench_highest_lowest_delta_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_highest_index_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = Highest::new(10, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = Highest::new(10, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -733,8 +733,8 @@ fn bench_highest_index_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_highest_index_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = Highest::new(100, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = Highest::new(100, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -745,8 +745,8 @@ fn bench_highest_index_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_lowest_index_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = Lowest::new(10, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = Lowest::new(10, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -756,8 +756,8 @@ fn bench_lowest_index_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_lowest_index_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = Lowest::new(100, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = Lowest::new(100, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -768,8 +768,8 @@ fn bench_lowest_index_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_mean_abs_dev_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = MeanAbsDev::new(10, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = MeanAbsDev::new(10, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -779,8 +779,8 @@ fn bench_mean_abs_dev_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_mean_abs_dev_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = MeanAbsDev::new(100, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = MeanAbsDev::new(100, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -791,8 +791,8 @@ fn bench_mean_abs_dev_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_median_abs_dev_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = MedianAbsDev::new(10, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = MedianAbsDev::new(10, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -802,8 +802,8 @@ fn bench_median_abs_dev_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_median_abs_dev_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = MedianAbsDev::new(100, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = MedianAbsDev::new(100, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -814,8 +814,8 @@ fn bench_median_abs_dev_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_cci_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = CCI::new(10, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = CCI::new(10, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -825,8 +825,8 @@ fn bench_cci_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_cci_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = CCI::new(100, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = CCI::new(100, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -837,8 +837,8 @@ fn bench_cci_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_tsi_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = TSI::new(10, 10, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = TSI::new(10, 10, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -848,8 +848,8 @@ fn bench_tsi_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_tsi_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = TSI::new(100, 100, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = TSI::new(100, 100, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -868,8 +868,8 @@ fn bench_tr(b: &mut test::Bencher) {
 #[bench]
 fn bench_vidya_w10(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = Vidya::new(10, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = Vidya::new(10, &candles[0]).unwrap();
 	for _ in 0..10 {
 		method.next(iter.next().unwrap());
 	}
@@ -879,8 +879,8 @@ fn bench_vidya_w10(b: &mut test::Bencher) {
 #[bench]
 fn bench_vidya_w100(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).map(|c| c.close).collect();
-	let mut iter = candles.iter().cycle().copied();
-	let mut method = Vidya::new(100, candles[0]).unwrap();
+	let mut iter = candles.iter().cycle();
+	let mut method = Vidya::new(100, &candles[0]).unwrap();
 	for _ in 0..100 {
 		method.next(iter.next().unwrap());
 	}
@@ -890,7 +890,7 @@ fn bench_vidya_w100(b: &mut test::Bencher) {
 #[bench]
 fn bench_heikin_ashi(b: &mut test::Bencher) {
 	let candles: Vec<_> = RandomCandles::new().take(1000).collect();
-	let mut iter = candles.iter().cycle().copied();
+	let mut iter = candles.iter().cycle();
 	let mut method = HeikinAshi::new((), &candles[0]).unwrap();
-	b.iter(|| method.next(&iter.next().unwrap()))
+	b.iter(|| method.next(iter.next().unwrap()))
 }
